diff --git a/htdocs/core/menus/init_menu_auguria.sql b/htdocs/core/menus/init_menu_auguria.sql
index 4dd1fd33d0fdd0571807bfcea24706604349154c..b1bc55be0a80be82b2d3937531d67892284670b0 100644
--- a/htdocs/core/menus/init_menu_auguria.sql
+++ b/htdocs/core/menus/init_menu_auguria.sql
@@ -299,7 +299,7 @@ insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, left
 insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->adherent->enabled && $conf->categorie->enabled', __HANDLER__, 'left', 5200__+MAX_llx_menu__, 'members', 'cat', 13__+MAX_llx_menu__, '/categories/index.php?leftmenu=cat&type=3', 'MembersCategoriesShort', 0, 'categories', '$user->rights->categorie->lire', '', 2, 3, __ENTITY__);
 insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->adherent->enabled && $conf->categorie->enabled', __HANDLER__, 'left', 5201__+MAX_llx_menu__, 'members', '', 5200__+MAX_llx_menu__, '/categories/card.php?action=create&type=3', 'NewCategory', 1, 'categories', '$user->rights->categorie->creer', '', 2, 0, __ENTITY__);
 -- HRM - Holiday
-insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->holiday->enabled', __HANDLER__, 'left', 5000__+MAX_llx_menu__, 'hrm', 'hrm', 15__+MAX_llx_menu__, '/holiday/index.php?&leftmenu=hrm', 'CPTitreMenu', 0, 'holiday', '$user->rights->holiday->write', '', 0, 1, __ENTITY__);
+insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->holiday->enabled', __HANDLER__, 'left', 5000__+MAX_llx_menu__, 'hrm', 'hrm', 15__+MAX_llx_menu__, '/holiday/list.php?&leftmenu=hrm', 'CPTitreMenu', 0, 'holiday', '$user->rights->holiday->write', '', 0, 1, __ENTITY__);
 insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->holiday->enabled', __HANDLER__, 'left', 5001__+MAX_llx_menu__, 'hrm', '', 5000__+MAX_llx_menu__, '/holiday/card.php?&action=request', 'MenuAddCP', 1, 'holiday', '$user->rights->holiday->write', '', 0, 1, __ENTITY__);
 insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->holiday->enabled', __HANDLER__, 'left', 5002__+MAX_llx_menu__, 'hrm', '', 5000__+MAX_llx_menu__, '/holiday/define_holiday.php?&action=request', 'MenuConfCP', 1, 'holiday', '$user->rights->holiday->define_holiday', '', 0, 2, __ENTITY__);
 insert into llx_menu (module, enabled, menu_handler, type, rowid, mainmenu, leftmenu, fk_menu, url, titre, level, langs, perms, target, usertype, position, entity) values ('', '$conf->holiday->enabled', __HANDLER__, 'left', 5003__+MAX_llx_menu__, 'hrm', '', 5000__+MAX_llx_menu__, '/holiday/view_log.php?&action=request', 'MenuLogCP', 1, 'holiday', '$user->rights->holiday->view_log', '', 0, 3, __ENTITY__);
diff --git a/htdocs/core/modules/DolibarrModules.class.php b/htdocs/core/modules/DolibarrModules.class.php
index d61296f0cc10eca90cab3c829f8e8f2fba1238e3..7471dd3ee0ddf4ef048114e61ef0cd07c33edde8 100644
--- a/htdocs/core/modules/DolibarrModules.class.php
+++ b/htdocs/core/modules/DolibarrModules.class.php
@@ -1691,11 +1691,13 @@ print $sql;
 
 	/**
 	 * Function called when module is enabled.
-	 * The init function add constants, boxes, permissions and menus (defined in constructor) into Dolibarr database.
+	 * The init function adds tabs, constants, boxes, permissions and menus (defined in constructor) into Dolibarr database.
 	 * It also creates data directories
 	 *
-	 * @param string $options    Options when enabling module ('', 'noboxes')
-	 * @return int             	1 if OK, 0 if KO
+	 * @param string $options   Options when enabling module ('', 'newboxdefonly', 'noboxes')
+     *                          'noboxes' = Do not insert boxes
+     *                          'newboxdefonly' = For boxes, insert def of boxes only and not boxes activation
+	 * @return int				1 if OK, 0 if KO
 	 */
 	public function init($options = '')
 	{
@@ -1704,11 +1706,11 @@ print $sql;
 
 	/**
 	 * Function called when module is disabled.
-	 * Remove from database constants, boxes and permissions from Dolibarr database.
+	 * The remove function removes tabs, constants, boxes, permissions and menus from Dolibarr database.
 	 * Data directories are not deleted
 	 *
 	 * @param      string	$options    Options when enabling module ('', 'noboxes')
-	 * @return     int             	1 if OK, 0 if KO
+	 * @return     int             		1 if OK, 0 if KO
 	 */
 	public function remove($options = '')
 	{
diff --git a/htdocs/core/modules/modExpenseReport.class.php b/htdocs/core/modules/modExpenseReport.class.php
index 690ca7ba87e732bd3739ca937600eb87c4e97752..123f4fe4aa04a75a38c7659e55f21ec8d22a5d16 100644
--- a/htdocs/core/modules/modExpenseReport.class.php
+++ b/htdocs/core/modules/modExpenseReport.class.php
@@ -139,7 +139,7 @@ class modExpenseReport extends DolibarrModules
 		$this->rights_class = 'expensereport';
 
 		$this->rights[1][0] = 771;
-		$this->rights[1][1] = 'Read expense reports (own and his subordinates)';
+		$this->rights[1][1] = 'Read expense reports (yours and your subordinates)';
 		$this->rights[1][2] = 'r';
 		$this->rights[1][3] = 1;
 		$this->rights[1][4] = 'lire';
diff --git a/htdocs/core/modules/modHoliday.class.php b/htdocs/core/modules/modHoliday.class.php
index 988391bca424c3cb2ea9b3a0a71d6ca2e8633c3d..b4517b4bfbea7668e8daf9c0f61c055f725fa6f7 100644
--- a/htdocs/core/modules/modHoliday.class.php
+++ b/htdocs/core/modules/modHoliday.class.php
@@ -180,88 +180,6 @@ class modHoliday extends DolibarrModules
 		$r=0;
 
 
-		/* Move to HRM menu
-		// Add here entries to declare new menus
-		$this->menu[$r]=array(	'fk_menu'=>0,			// Put 0 if this is a top menu
-								'type'=>'top',			// This is a Top menu entry
-								'titre'=>'CPTitreMenu',
-								'mainmenu'=>'holiday',
-								'leftmenu'=>'holiday',
-								'url'=>'/holiday/index.php',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>100,
-								'enabled'=>'1',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->write',			// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-		$this->menu[$r]=array(	'fk_menu'=>'fk_mainmenu=holiday',			// Put 0 if this is a top menu
-								'type'=>'left',			// This is a Top menu entry
-								'titre'=>'CPTitreMenu',
-								'mainmenu'=>'holiday',
-								'leftmenu'=>'holiday',
-								'url'=>'/holiday/index.php?mainmenu=holiday&leftmenu=holiday',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>100,
-								'enabled'=>'1',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->write',			// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-		$this->menu[$r]=array(	'fk_menu'=>'fk_mainmenu=holiday,fk_leftmenu=holiday',		// Use r=value where r is index key used for the parent menu entry (higher parent must be a top menu entry)
-								'type'=>'left',			// This is a Left menu entry
-								'titre'=>'MenuAddCP',
-								'mainmenu'=>'holiday',
-								'leftmenu'=>'holiday_add',
-								'url'=>'/holiday/card.php?mainmenu=holiday&action=request',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>101,
-								'enabled'=>'$conf->holiday->enabled',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->write',		// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-		$this->menu[$r]=array(	'fk_menu'=>'fk_mainmenu=holiday,fk_leftmenu=holiday',		// Use r=value where r is index key used for the parent menu entry (higher parent must be a top menu entry)
-								'type'=>'left',			// This is a Left menu entry
-								'titre'=>'MenuConfCP',
-								'mainmenu'=>'holiday',
-								'leftmenu'=>'holiday_conf',
-								'url'=>'/holiday/define_holiday.php?mainmenu=holiday&action=request',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>102,
-								'enabled'=>'$conf->holiday->enabled',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->define_holiday',		// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-		$this->menu[$r]=array(	'fk_menu'=>'fk_mainmenu=holiday,fk_leftmenu=holiday',		// Use r=value where r is index key used for the parent menu entry (higher parent must be a top menu entry)
-								'type'=>'left',			// This is a Left menu entry
-								'titre'=>'MenuLogCP',
-								'mainmenu'=>'holiday_def',
-								'url'=>'/holiday/view_log.php?mainmenu=holiday&action=request',
-								'leftmenu'=>'holiday',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>103,
-								'enabled'=>'$conf->holiday->enabled',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->view_log',		// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-		$this->menu[$r]=array(	'fk_menu'=>'fk_mainmenu=holiday,fk_leftmenu=holiday',		// Use r=value where r is index key used for the parent menu entry (higher parent must be a top menu entry)
-								'type'=>'left',			// This is a Left menu entry
-								'titre'=>'MenuReportMonth',
-								'mainmenu'=>'holiday',
-								'leftmenu'=>'holiday_report',
-								'url'=>'/holiday/month_report.php?mainmenu=holiday&action=request',
-								'langs'=>'holiday',	// Lang file to use (without .lang) by module. File must be in langs/code_CODE/ directory.
-								'position'=>104,
-								'enabled'=>'$conf->holiday->enabled',			// Define condition to show or hide menu entry. Use '$conf->mymodule->enabled' if entry must be visible if module is enabled.
-								'perms'=>'$user->rights->holiday->view_log',		// Use 'perms'=>'$user->rights->mymodule->level1->level2' if you want your menu with a permission rules
-								'target'=>'',
-								'user'=>2);				// 0=Menu for internal users, 1=external users, 2=both
-		$r++;
-*/
-
 		// Exports
 		$r=1;
 
diff --git a/htdocs/holiday/list.php b/htdocs/holiday/list.php
index c350fb003e679667ae5057908335766fca368001..4e10fbf925c5014482ff77824cb0be639b0b8cab 100644
--- a/htdocs/holiday/list.php
+++ b/htdocs/holiday/list.php
@@ -18,7 +18,7 @@
  */
 
 /**
- *   	\file       htdocs/holiday/index.php
+ *   	\file       htdocs/holiday/list.php
  *		\ingroup    holiday
  *		\brief      List of holiday.
  */
diff --git a/htdocs/langs/en_US/admin.lang b/htdocs/langs/en_US/admin.lang
index 5f2d3eba8c63169133ae281672267febe4ad98c8..74947e5e0d902c2d8855bdc89da30a3fb68afd16 100755
--- a/htdocs/langs/en_US/admin.lang
+++ b/htdocs/langs/en_US/admin.lang
@@ -635,7 +635,7 @@ Permission162=Create/modify contracts/subscriptions
 Permission163=Activate a service/subscription of a contract
 Permission164=Disable a service/subscription of a contract
 Permission165=Delete contracts/subscriptions
-Permission171=Read trips and expenses (own and his subordinates) 
+Permission171=Read trips and expenses (yours and your subordinates) 
 Permission172=Create/modify trips and expenses
 Permission173=Delete trips and expenses
 Permission174=Read all trips and expenses 
@@ -730,7 +730,7 @@ Permission538=Export services
 Permission701=Read donations
 Permission702=Create/modify donations
 Permission703=Delete donations
-Permission771=Read expense reports (own and his subordinates) 
+Permission771=Read expense reports (yours and your subordinates) 
 Permission772=Create/modify expense reports
 Permission773=Delete expense reports
 Permission774=Read all expense reports (even for user not subordinates)
@@ -767,6 +767,12 @@ Permission1237=Export supplier orders and their details
 Permission1251=Run mass imports of external data into database (data load)
 Permission1321=Export customer invoices, attributes and payments
 Permission1421=Export customer orders and attributes
+Permission20001=Read leave requests (yours and your subordinates)
+Permission20002=Create/modify your leave requests
+Permission20003=Delete leave requests
+Permission20004=Read all leave requests (even user not subordinates)
+Permission20005=Create/modify leave requests for everybody
+Permission20006=Admin leave requests (setup and update balance)
 Permission23001=Read Scheduled job
 Permission23002=Create/update Scheduled job
 Permission23003=Delete Scheduled job
diff --git a/htdocs/langs/en_US/holiday.lang b/htdocs/langs/en_US/holiday.lang
index 9bf90c3d01c08a20f855e9a69b46f38225b5b89e..725336d8790414dfbce8decff19bea9188da0776 100644
--- a/htdocs/langs/en_US/holiday.lang
+++ b/htdocs/langs/en_US/holiday.lang
@@ -140,11 +140,5 @@ HolidaysRefused=Request denied
 HolidaysRefusedBody=Your leave request for %s to %s has been denied for the following reason :
 HolidaysCanceled=Canceled leaved request
 HolidaysCanceledBody=Your leave request for %s to %s has been canceled.
-Permission20001=Read you own leave requests
-Permission20002=Create/modify your leave requests
-Permission20003=Delete leave requests
-Permission20004=Read leave requests for everybody
-Permission20005=Create/modify leave requests for everybody
-Permission20006=Admin leave requests (setup and update balance)
 NewByMonth=Added per month
 GoIntoDictionaryHolidayTypes=Go into <strong>Home - Setup - Dictionaries - Type of leaves</strong> to setup the different types of leaves.
\ No newline at end of file
diff --git a/htdocs/langs/en_US/install.lang b/htdocs/langs/en_US/install.lang
index fada78c04c6354a44ffda8eb4b9c81ceb42b9121..6ec3ca2d14a51d411ae25e533d41b33fa2e7dfde 100644
--- a/htdocs/langs/en_US/install.lang
+++ b/htdocs/langs/en_US/install.lang
@@ -209,6 +209,6 @@ MigrationActioncommElement=Update data on actions
 MigrationPaymentMode=Data migration for payment mode
 MigrationCategorieAssociation=Migration of categories
 MigrationEvents=Migration of events to add event owner into assignement table
-
+MigrationReloadModule=Reload module %s
 ShowNotAvailableOptions=Show not available options
 HideNotAvailableOptions=Hide not available options
diff --git a/htdocs/langs/fr_FR/holiday.lang b/htdocs/langs/fr_FR/holiday.lang
index c3dfa31de0784d14234b917d933c7e03042fa725..d201181188df61cd78ff3a3b53eb59fdd19f6edb 100644
--- a/htdocs/langs/fr_FR/holiday.lang
+++ b/htdocs/langs/fr_FR/holiday.lang
@@ -140,11 +140,5 @@ HolidaysRefused=Accès refusé
 HolidaysRefusedBody=Votre demande de congés payés %s à %s vient d'être refusée pour le motif suivant :
 HolidaysCanceled=Abandonner la demande de congés
 HolidaysCanceledBody=Votre demande de congés du %s au %s a été annulée.
-Permission20001=Lire ses propres demandes de congès
-Permission20002=Créer/modifier ses demandes de congés
-Permission20003=Supprimer la demande de Congés
-Permission20004=Lire les demandes de congès de tout le monde
-Permission20005=Créer/modifier les congés pour tout le monde
-Permission20006=Administration des demande de congès (configuration et mise à jour du solde)
 NewByMonth=Ajouté par mois
 GoIntoDictionaryHolidayTypes=Aller dans <strong>Accueil - Configuration - Dictionnaires - Type de congés</strong> pour configurer les différents types de congés.
diff --git a/htdocs/install/upgrade2.php b/htdocs/install/upgrade2.php
index 214a6c54fbfdc626d32ead892a9c55a9395e585e..f42e55cb6970ebb993de635078ec77fcd390bb45 100644
--- a/htdocs/install/upgrade2.php
+++ b/htdocs/install/upgrade2.php
@@ -366,29 +366,29 @@ if (! GETPOST("action") || preg_match('/upgrade/i',GETPOST('action')))
        	    migrate_event_assignement($db,$langs,$conf);
         }
 
-        // Scripts for lat version
+        // Scripts for last version
         $afterversionarray=explode('.','3.7.9');
         $beforeversionarray=explode('.','3.8.9');
         if (versioncompare($versiontoarray,$afterversionarray) >= 0 && versioncompare($versiontoarray,$beforeversionarray) <= 0)
         {
         	// Reload modules (this must be always and only into last targeted version)
 			$listofmodule=array(
-				    	'MAIN_MODULE_AGENDA',
-						'MAIN_MODULE_BARCODE',
-						'MAIN_MODULE_CRON',
-				    	'MAIN_MODULE_COMMANDE',
-				    	'MAIN_MODULE_DEPLACEMENT',
-				    	'MAIN_MODULE_DON',
-				    	'MAIN_MODULE_ECM',
-				    	'MAIN_MODULE_FACTURE',
-				    	'MAIN_MODULE_FOURNISSEUR',
-						'MAIN_MODULE_HOLIDAY',
-						'MAIN_MODULE_OPENSURVEY',
-						'MAIN_MODULE_PAYBOX',
-						'MAIN_MODULE_PRODUIT',
-						'MAIN_MODULE_SOCIETE',
-				    	'MAIN_MODULE_SERVICE',
-						'MAIN_MODULE_USER'
+				    	'MAIN_MODULE_AGENDA'=>'newboxdefonly',
+						'MAIN_MODULE_BARCODE'=>'newboxdefonly',
+						'MAIN_MODULE_CRON'=>'newboxdefonly',
+				    	'MAIN_MODULE_COMMANDE'=>'newboxdefonly',
+				    	'MAIN_MODULE_DEPLACEMENT'=>'newboxdefonly',
+				    	'MAIN_MODULE_DON'=>'newboxdefonly',
+				    	'MAIN_MODULE_ECM'=>'newboxdefonly',
+				    	'MAIN_MODULE_FACTURE'=>'newboxdefonly',
+				    	'MAIN_MODULE_FOURNISSEUR'=>'newboxdefonly',
+						'MAIN_MODULE_HOLIDAY'=>'newboxdefonly',
+						'MAIN_MODULE_OPENSURVEY'=>'newboxdefonly',
+						'MAIN_MODULE_PAYBOX'=>'newboxdefonly',
+						'MAIN_MODULE_PRODUIT'=>'newboxdefonly',
+						'MAIN_MODULE_SOCIETE'=>'newboxdefonly',
+				    	'MAIN_MODULE_SERVICE'=>'newboxdefonly',
+						'MAIN_MODULE_USER'=>'newboxdefonly'
 			);
         	migrate_reload_modules($db,$langs,$conf,$listofmodule);
 
@@ -3750,30 +3750,33 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 {
     dolibarr_install_syslog("upgrade2::migrate_reload_modules");
 
     // Module to reload if no info is provided
     if (count($listofmodule) == 0)
     {
     	$listofmodule=array(
-	    	'MAIN_MODULE_AGENDA',
-	    	'MAIN_MODULE_SOCIETE',
-	    	'MAIN_MODULE_PRODUIT',
-	    	'MAIN_MODULE_SERVICE',
-	    	'MAIN_MODULE_COMMANDE',
-	    	'MAIN_MODULE_FACTURE',
-	    	'MAIN_MODULE_FOURNISSEUR',
-	    	'MAIN_MODULE_USER',
-	    	'MAIN_MODULE_DEPLACEMENT',
-	    	'MAIN_MODULE_DON',
-	    	'MAIN_MODULE_ECM',
-	    	'MAIN_MODULE_PAYBOX',
-    		'MAIN_MODULE_OPENSURVEY'
+	    	'MAIN_MODULE_AGENDA'=>'newboxdefonly',
+	    	'MAIN_MODULE_SOCIETE'=>'newboxdefonly',
+	    	'MAIN_MODULE_PRODUIT'=>'newboxdefonly',
+	    	'MAIN_MODULE_SERVICE'=>'newboxdefonly',
+	    	'MAIN_MODULE_COMMANDE'=>'newboxdefonly',
+	    	'MAIN_MODULE_FACTURE'=>'newboxdefonly',
+	    	'MAIN_MODULE_FOURNISSEUR'=>'newboxdefonly',
+    		'MAIN_MODULE_HOLIDAY'=>'newboxdefonly',
+    		'MAIN_MODULE_USER'=>'newboxdefonly',
+	    	'MAIN_MODULE_DEPLACEMENT'=>'newboxdefonly',
+	    	'MAIN_MODULE_DON'=>'newboxdefonly',
+	    	'MAIN_MODULE_ECM'=>'newboxdefonly',
+	    	'MAIN_MODULE_PAYBOX'=>'newboxdefonly',
+    		'MAIN_MODULE_OPENSURVEY'=>'newboxdefonly'
     	);
     }
 
-    foreach($listofmodule as $moduletoreload)
+    foreach($listofmodule as $moduletoreload => $reloadmode)
     {
     	if (empty($moduletoreload) || empty($conf->global->$moduletoreload)) continue;
 
+    	$mod=null;
+    	
 	    if ($moduletoreload == 'MAIN_MODULE_AGENDA')
 	    {
 	        dolibarr_install_syslog("upgrade2::migrate_reload_modules Reactivate Agenda module");
@@ -3781,7 +3784,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modAgenda($db);
 	            $mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
         if ($moduletoreload == 'MAIN_MODULE_BARCODE')
@@ -3791,7 +3794,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modBarcode($db);
 	            $mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_CRON')
@@ -3801,7 +3804,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modCron($db);
 	            $mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_SOCIETE')
@@ -3811,7 +3814,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modSociete($db);
 	            $mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_PRODUIT')    // Permission has changed into 2.7
@@ -3821,7 +3824,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modProduct($db);
 	            //$mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_SERVICE')    // Permission has changed into 2.7
@@ -3832,7 +3835,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modService($db);
 	            //$mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_COMMANDE')   // Permission has changed into 2.9
@@ -3843,7 +3846,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modCommande($db);
 	            //$mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_FACTURE')    // Permission has changed into 2.9
@@ -3853,7 +3856,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modFacture($db);
 	            //$mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_FOURNISSEUR')    // Permission has changed into 2.9
@@ -3863,7 +3866,17 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modFournisseur($db);
 	            //$mod->remove('noboxes');
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
+	        }
+	    }
+    	if ($moduletoreload == 'MAIN_MODULE_HOLIDAY')    // Permission and tabs has changed into 3.8
+	    {
+	        dolibarr_install_syslog("upgrade2::migrate_reload_modules Reactivate Leave Request module");
+	        $res=@include_once DOL_DOCUMENT_ROOT.'/core/modules/modHoliday.class.php';
+	        if ($res) {
+	            $mod=new modHoliday($db);
+	            $mod->remove('noboxes');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_DEPLACEMENT')    // Permission has changed into 3.0
@@ -3872,8 +3885,8 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        $res=@include_once DOL_DOCUMENT_ROOT.'/core/modules/modDeplacement.class.php';
 	        if ($res) {
 	            $mod=new modDeplacement($db);
-	            //$mod->remove('noboxes');	// We need to remove because a permission id has been removed
-	            $mod->init('newboxdefonly');
+	            //$mod->remove('noboxes');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_DON')    // Permission has changed into 3.0
@@ -3882,8 +3895,8 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        $res=@include_once DOL_DOCUMENT_ROOT.'/core/modules/modDon.class.php';
 	        if ($res) {
 	            $mod=new modDon($db);
-	            //$mod->remove('noboxes');	// We need to remove because a permission id has been removed
-	            $mod->init('newboxdefonly');
+	            //$mod->remove('noboxes');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_ECM')    // Permission has changed into 3.0 and 3.1
@@ -3893,7 +3906,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modECM($db);
 	            $mod->remove('noboxes');	// We need to remove because a permission id has been removed
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
 	    if ($moduletoreload == 'MAIN_MODULE_PAYBOX')    // Permission has changed into 3.0
@@ -3903,7 +3916,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modPaybox($db);
 	            $mod->remove('noboxes');  // We need to remove because id of module has changed
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
     	if ($moduletoreload == 'MAIN_MODULE_OPENSURVEY')    // Permission has changed into 3.0
@@ -3913,7 +3926,7 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        if ($res) {
 	            $mod=new modOpenSurvey($db);
 	            $mod->remove('noboxes');  // We need to remove because menu entries has changed
-	            $mod->init('newboxdefonly');
+	            $mod->init($reloadmode);
 	        }
 	    }
     	if ($moduletoreload == 'MAIN_MODULE_USER')    // Permission has changed into 3.0
@@ -3922,11 +3935,20 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
 	        $res=@include_once DOL_DOCUMENT_ROOT.'/core/modules/modUser.class.php';
 	        if ($res) {
 	            $mod=new modUser($db);
-	            //$mod->remove('noboxes');  // We need to remove because id of module has changed
-	            $mod->init('newboxdefonly');
+	            //$mod->remove('noboxes');
+	            $mod->init($reloadmode);
 	        }
 	    }
 
+		if (! empty($mod) && is_object($mod))
+		{	    
+    		print '<tr><td colspan="4">';
+        	print '<b>'.$langs->trans('Upgrade').'</b>: ';
+        	print $langs->trans('MigrationReloadModule')." ".$mod->getName();
+        	print "<!-- (".$reloadmode.") -->";
+        	print "<br>\n";
+        	print '</td></tr>';
+		}
     }
 }
 
@@ -3951,7 +3973,7 @@ function migrate_reload_menu($db,$langs,$conf,$versionto)
 
     $versiontoarray=explode('.',$versionto);
 
-    // Script for VX (X<2.9) -> V2.9
+    // Migration required when target version is between 
     $afterversionarray=explode('.','2.8.9');
     $beforeversionarray=explode('.','2.9.9');
     if (versioncompare($versiontoarray,$afterversionarray) >= 0 && versioncompare($versiontoarray,$beforeversionarray) <= 0)
@@ -3959,7 +3981,7 @@ function migrate_reload_menu($db,$langs,$conf,$versionto)
         $listofmenuhandler['auguria']=1;   // We set here only dynamic menu handlers
     }
 
-    // Script for VX (X<3.2) -> V3.2
+    // Migration required when target version is between 
     $afterversionarray=explode('.','3.1.9');
     $beforeversionarray=explode('.','3.2.9');
     if (versioncompare($versiontoarray,$afterversionarray) >= 0 && versioncompare($versiontoarray,$beforeversionarray) <= 0)
@@ -3967,6 +3989,14 @@ function migrate_reload_menu($db,$langs,$conf,$versionto)
         $listofmenuhandler['auguria']=1;   // We set here only dynamic menu handlers
     }
 
+    // Migration required when target version is between 
+    $afterversionarray=explode('.','3.7.9');
+    $beforeversionarray=explode('.','3.8.9');
+    if (versioncompare($versiontoarray,$afterversionarray) >= 0 && versioncompare($versiontoarray,$beforeversionarray) <= 0)
+    {
+        $listofmenuhandler['auguria']=1;   // We set here only dynamic menu handlers
+    }
+
     foreach ($listofmenuhandler as $key => $val)
     {
         print '<tr><td colspan="4">';
@@ -3750,30 +3750,33 @@ function migrate_reload_modules($db,$langs,$conf,$listofmodule=array())
     dolibarr_install_syslog("upgrade2::migrate_reload_modules");
 
-    // Module to reload if no info is provided
+    // If no info is provided, we reload all modules with mode newboxdefonly.
     if (count($listofmodule) == 0)
     {